## Schematic

- A changing magnetic field induces a voltage across a conductor placed in it.
- In this case we drop a magnet through a coil and measure the induced voltage as a function of time.

## Instructions

- Connect the coil.
- Insert a paper tube to guide the magnet through the coil.
- Press 'Start scanning" and drop the magnet.
- It may take several tries to get a trace, because the scanning and movement of the magnet need to coinside, to get the trace